@@ -97,7 +97,7 @@ DolphinView::DolphinView(const QUrl& url, QWidget* parent) :
 {
     m_topLayout = new QVBoxLayout(this);
     m_topLayout->setSpacing(0);
-    m_topLayout->setMargin(0);
+    m_topLayout->setContentsMargins(0, 0, 0, 0);
 
     // When a new item has been created by the "Create New..." menu, the item should
     // get selected and it must be assured that the item will get visible. As the
@@ -639,9 +639,7 @@ void DolphinView::renameSelectedItems()
         RenameDialog* dialog = new RenameDialog(this, items);
         connect(dialog, &RenameDialog::renamingFinished, this, &DolphinView::slotRenameDialogRenamingFinished);
 
-        dialog->show();
-        dialog->raise();
-        dialog->activateWindow();
+        dialog->open();
     }
 
     // Assure that the current index remains visible when KFileItemModel
@@ -855,7 +853,7 @@ void DolphinView::slotItemsActivated(const KItemSet& indexes)
         const QUrl& url = openItemAsFolderUrl(item);
 
         if (!url.isEmpty()) { // Open folders in new tabs
-            emit tabRequested(url);
+            emit tabRequested(url, DolphinTabWidget::AfterLastTab);
         } else {
             items.append(item);
         }
@@ -873,9 +871,9 @@ void DolphinView::slotItemMiddleClicked(int index)
     const KFileItem& item = m_model->fileItem(index);
     const QUrl& url = openItemAsFolderUrl(item);
     if (!url.isEmpty()) {
-        emit tabRequested(url);
+        emit tabRequested(url, DolphinTabWidget::AfterCurrentTab);
     } else if (isTabsForFilesEnabled()) {
-        emit tabRequested(item.url());
+        emit tabRequested(item.url(), DolphinTabWidget::AfterCurrentTab);
     }
 }
 
